Cosmic in Python — Cosmic 0.4.0 documentation

### Navigation

- index
- modules |
- next |
- Cosmic 0.4.0 documentation »

# Cosmic in Python

Here you will find the documentation for the Python implementation of Cosmic. The tutorial should be the best way to get up and running.

Contents:

- Overview
  - REST and RPC
  - Architecture
  - Built on Teleport
  - Hypermedia with JSON HAL
- Tutorial
  - Step 1: Single-function API
  - Step 2: Making a REST Model
  - Step 3: Authenticating
- Guide
  - Installation
  - What’s in an API?
  - Auto-generated Clients
  - RPC via Actions
  - REST via Models
    - get_by_id
    - create
    - update
    - delete
    - get_list
  - Serving
  - Authentication
  - Storing Global Data
- Reference
  - APIs
  - Models
  - Types
  - HTTP Endpoints
  - Exceptions
  - Tools and Helpers
- Changelog
  - Version 0.4.1

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- Cosmic 0.4.0 documentation »